"use client";

import Image from "next/image";
import Link from "next/link";
import * as React from "react";

import useEmblaCarousel from "embla-carousel-react";
import { CheckCircle } from "lucide-react";

import { Badge } from "@/components/ui/badge";
import { Button } from "@/components/ui/button";
import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";

import { ContentLines } from "@/components/shared/content-lines";
import { ImageBaseUrl } from "@/configs/api";
import { useProject } from "@/servers/data/use-project";
import { useLocale, useTranslations } from "next-intl";
import { useEffect } from "react";


export default function VideoProfileClient() {
	const locale = useLocale() as Locale;
	const t = useTranslations();
	const { projects } = useProject(3);
	const videoRef = React.useRef<HTMLVideoElement>(null);

	const isRTL = locale === "ar";
	const [activeProjectIndex, setActiveProjectIndex] = React.useState(0);
	const [selectedImage, setSelectedImage] = React.useState("");
	const [selectedVideo, setSelectedVideo] = React.useState<any>(projects[0]);
	const [isPlaying, setIsPlaying] = React.useState(false);


	useEffect(() => {
		setSelectedVideo(projects[0]);
		setSelectedImage(projects[0]?.images[0]?.image_path);
	}, [projects]);


	// console.log("activeProjectIndex:", activeProjectIndex);
	// console.log("projects:", projects);

	// Video thumbnails carousel
	const [videoEmblaRef] = useEmblaCarousel({
		align: "start",
		containScroll: "trimSnaps",
		direction: isRTL ? "rtl" : "ltr",
	});

	// Projects carousel
	const [projectEmblaRef, projectEmblaApi] = useEmblaCarousel({
		align: "start",
		containScroll: "trimSnaps",
		direction: isRTL ? "rtl" : "ltr",
	});


	const toggleVideo = () => {
		setIsPlaying(true);
	};

	return (
		projects?.length > 0 &&
		<section className="bg-gray-image px-4 py-16 md:px-8 lg:px-40">
			<div className="grid grid-cols-1 gap-8 lg:grid-cols-2">
				{/* Content Section */}
				<div
					className={cn(
						"flex h-[500px] max-w-[674px] flex-col justify-around rounded-lg bg-custom-background-light px-6 py-12 shadow-[0_78px_34px_-45px_rgba(0,0,0,0.15)]",
					)}
				>
					<div className="mb-8 flex flex-col">
						{/* Section T*/}

						<ContentLines
							title={t("Projects")}
							underlineColor="custom-primary-accent"
							textColor="text-custom-primary-accent"
						/>
						{/* Project Content */}
						<div className="overflow-hidden" ref={projectEmblaRef}>
							<div className="flex">
								{projects?.map((project: any) => (
									<div
										key={project?.id}
										className="relative mr-4 min-w-0 flex-[0_0_100%]"
									>
										<h2 className="mb-4 text-4xl font-semibold">
											{locale === "ar" ? project?.title_ar : project?.title_en}
										</h2>
										<p className="mb-8 leading-relaxed text-gray-600">
											{locale === "ar" ? project?.description_ar : project?.description_en}
										</p>
										<div className={cn("flex flex-wrap gap-3")}>
											{project?.tags?.map((_tag: any) => (
												<Badge
													key={_tag?.id}
													variant="outline"
													className={cn(
														"flex items-center gap-2 rounded-full border-custom-primary-accent px-4 py-1.5 text-custom-primary-accent",
													)}
													style={{ backgroundColor: "rgb(40 149 200 / 9%)" }}
												>
													{isRTL ? _tag?.ar_name : _tag?.en_name}
													<CheckCircle className="h-4 w-4" />
												</Badge>
											))}
										</div>
									</div>
								))}
							</div>
						</div>
					</div>

					{/* Project Navigation */}
					<div
						className={cn(
							"mt-auto flex w-full items-center justify-between gap-4"
						)}
					>
						<Link href={`/${locale}/projects`}>
							<Button className="bg-[#2895C8] hover:bg-custom-primary-accent/80">
								{t("All Projects")}
							</Button>
						</Link>

						{projects?.length > 1 && <div className="flex gap-2">
							{
								projects?.map((_: any, index: number) => (
									<button
										key={index}
										className={cn(
											"h-3 w-3 rounded-full transition-colors",
											index === activeProjectIndex
												? "bg-blue-500"
												: "bg-gray-300 hover:bg-gray-400"
										)}
										onClick={() => {
											setActiveProjectIndex(index);
											projectEmblaApi?.scrollTo(index);
											setSelectedVideo(projects[index]);
											setIsPlaying(false);
											setSelectedImage(projects[index]?.images[0]?.image_path);
										}}
									/>
								))}
						</div>}
					</div>
				</div>

				{/* Video Section */}
				<div className="relative">
					{/* Main Video */}
					<div className="relative aspect-video w-full overflow-hidden rounded-lg bg-gray-100">
						{isPlaying ? (
							<video
								ref={videoRef}
								src={ImageBaseUrl + selectedVideo?.video}
								className="h-full w-full"
								controls
								autoPlay
								onEnded={() => setIsPlaying(false)}
							/>
						) : (
							<>
								<Image
									src={ImageBaseUrl + selectedImage}
									alt="Video thumbnail"
									fill
									className="object-cover"
								/>
								{projects?.[activeProjectIndex]?.thumbnail?.image_path === selectedImage && <button
									onClick={toggleVideo}
									className="absolute inset-0 flex items-center justify-center"
								>
									<div className="flex h-20 w-20 items-center justify-center rounded-full bg-white/20 transition-colors hover:bg-white/30">
										<div className="flex h-16 w-16 items-center justify-center rounded-full bg-white">
											<div className="ml-1 h-0 w-0 border-y-[12px] border-l-[20px] border-y-transparent border-l-blue-500" />
										</div>
									</div>
								</button>}

							</>
						)}
					</div>

					{/* Video Thumbnails Carousel */}
					<div className="relative mt-4">
						<div className="overflow-hidden" ref={videoEmblaRef}>
							<div className="flex touch-pan-y">
								{projects?.[activeProjectIndex]?.images?.map((_img: any) => (
									<div
										key={_img?.id}
										className="relative mr-4 min-w-0 flex-[0_0_20%]"
									>
										<button
											onClick={() => {
												setSelectedVideo(projects?.[activeProjectIndex]);
												setIsPlaying(false);
												setSelectedImage(_img?.image_path);
											}}
											className={cn(
												"relative aspect-video w-full overflow-hidden rounded-lg",
												selectedImage === _img?.image_path &&
												"ring-2 ring-blue-500 ring-offset-2"
											)}
										>
											<Image
												src={ImageBaseUrl + _img?.image_path}
												alt={_img?.name}
												fill
												className="object-cover"
											/>
										</button>
									</div>
								))}
							</div>
						</div>
					</div>
				</div>
			</div>
		</section>
	);
}
